@@ -3,9 +3,11 @@ from .insertion_encodable import (
     is_insertion_encodable_maximum,
     is_insertion_encodable_rightmost,
 )
+from .symmetry import lex_min
 
 __all__ = [
     "is_insertion_encodable",
     "is_insertion_encodable_maximum",
     "is_insertion_encodable_rightmost",
+    "lex_min",
 ]
